@@ -4,6 +4,8 @@ from datetime import datetime
 import pymongo
 from bson import ObjectId
 
+from scout.constants import DATE_DAY_FORMATTER
+
 from .case_events import CaseEventHandler
 from .variant_events import VariantEventHandler
 
@@ -34,7 +36,9 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
         }  # Return only events created by given user
         add_fields = {
             "$addFields": {
-                "yearMonthDay": {"$dateToString": {"format": "%Y-%m-%d", "date": "$updated_at"}},
+                "yearMonthDay": {
+                    "$dateToString": {"format": DATE_DAY_FORMATTER, "date": "$updated_at"}
+                },
             }
         }  # Create an additional field: yearMonthDay to group and display events better later
         group = {
@@ -109,6 +113,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
             event(dict): The inserted event
         """
         variant = variant or {}
+        current_time = datetime.now()
         event = dict(
             institute=institute["_id"],
             case=case["_id"],
@@ -122,8 +127,8 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
             variant_id=variant.get("variant_id"),
             content=content,
             panel=panel,
-            created_at=datetime.now(),
-            updated_at=datetime.now(),
+            created_at=current_time,
+            updated_at=current_time,
         )
         if individuals:
             event["individuals"] = individuals
@@ -509,6 +514,7 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
             },
         )
         # create an event to register that user has updated a comment
+        current_time = datetime.now()
         event = dict(
             institute=updated_comment["institute"],
             case=updated_comment["case"],
@@ -522,8 +528,8 @@ class EventHandler(CaseEventHandler, VariantEventHandler):
             variant_id=updated_comment.get("variant_id", None),
             content=None,
             panel=None,
-            created_at=datetime.now(),
-            updated_at=datetime.now(),
+            created_at=current_time,
+            updated_at=current_time,
         )
         self.event_collection.insert_one(event)
         return updated_comment
