@@ -4,10 +4,8 @@ import logging
 import click
 from flask.cli import current_app, with_appcontext
 
-from scout.load.panel import load_panel, load_panel_app
+from scout.load.panel import load_omim_panel, load_panel, load_panelapp_panel
 from scout.server.extensions import store
-from scout.utils.handle import get_file_handle
-from scout.utils.scout_requests import fetch_mim_files
 
 LOG = logging.getLogger(__name__)
 
@@ -50,6 +48,13 @@ LOG = logging.getLogger(__name__)
 )
 @click.option("--api-key", help="A OMIM api key, see https://omim.org/api.")
 @click.option("--panel-app", is_flag=True, help="Load all PanelApp panels into scout.")
+@click.option(
+    "--panel-app-confidence",
+    type=click.Choice(
+        ["green", "amber", "red"],
+        case_sensitive=True,
+    ),
+)
 @with_appcontext
 def panel(
     path,
@@ -65,6 +70,7 @@ def panel(
     mim2genes,
     api_key,
     panel_app,
+    panel_app_confidence,
 ):
     """Add a gene panel to the database."""
 
@@ -72,15 +78,13 @@ def panel(
     institute = institute or "cust000"
 
     if omim:
-        _panel_omim(adapter, genemap2, mim2genes, api_key, institute)
+        load_omim_panel(adapter, genemap2, mim2genes, api_key, institute)
         return
 
     if panel_app:
-        # try:
-        load_panel_app(adapter, panel_id, institute=institute)
-        # except Exception as err:
-        #     LOG.warning(err)
-        #     raise click.Abort()
+        load_panelapp_panel(
+            adapter, panel_id, institute=institute, confidence=panel_app_confidence or "green"
+        )
         return
 
     if path is None:
@@ -101,53 +105,3 @@ def panel(
     except Exception as err:
         LOG.warning(err)
         raise click.Abort()
-
-    return
-
-
-def _panel_omim(adapter, genemap2, mim2genes, api_key, institute):
-    """Add OMIM panel to the database.
-    Args:
-        adapter(scout.adapter.MongoAdapter)
-        genemap2(str): Path to file in omim genemap2 format
-        mim2genes(str): Path to file in omim mim2genes format
-        api_key(str): OMIM API key
-        institute(str): institute _id
-    """
-
-    mim_files = None
-    if genemap2 and mim2genes:
-        mim_files = {
-            "genemap2": list(get_file_handle(genemap2)),
-            "mim2genes": list(get_file_handle(mim2genes)),
-        }
-
-    api_key = api_key or current_app.config.get("OMIM_API_KEY")
-    if not api_key and mim_files is None:
-        LOG.warning(
-            "Please provide either an OMIM api key or the path to genemap2 and mim2genesto to load the omim gene panel"
-        )
-        raise click.Abort()
-    # Check if OMIM-AUTO exists
-    if adapter.gene_panel(panel_id="OMIM-AUTO"):
-        LOG.warning(
-            "OMIM-AUTO already exists in database. Use the command 'scout update omim' to create a new OMIM panel version"
-        )
-        return
-
-    if not mim_files:
-        try:
-            mim_files = fetch_mim_files(api_key=api_key, genemap2=True, mim2genes=True)
-        except Exception as err:
-            raise err
-
-    # Here we know that there is no panel loaded
-    try:
-        adapter.load_omim_panel(
-            genemap2_lines=mim_files["genemap2"],
-            mim2gene_lines=mim_files["mim2genes"],
-            institute=institute,
-        )
-    except Exception as err:
-        LOG.error(err)
-        raise click.Abort()
