@@ -7,7 +7,7 @@ LOG = logging.getLogger(__name__)
 
 
 def add_panel_specific_gene_info(panel_info):
-    """Adds manualy curated information from a gene panel to a gene
+    """Adds manually curated information from a gene panel to a gene
 
     The panel info is a list of dictionaries since there can be multiple infos about a panel.
 
@@ -25,6 +25,7 @@ def add_panel_specific_gene_info(panel_info):
     manual_penetrance = False
     mosaicism = False
     manual_inheritance = set()
+    comment = list()
 
     # We need to loop since there can be information from multiple panels
     for gene_info in panel_info:
@@ -41,6 +42,11 @@ def add_panel_specific_gene_info(panel_info):
         if gene_info.get("mosaicism"):
             mosaicism = True
 
+        if gene_info.get("comment"):
+            panel_gene_comment = gene_info.get("comment")
+            if panel_gene_comment:
+                comment.append(panel_gene_comment)
+
         manual_inheritance.update(gene_info.get("inheritance_models", []))
 
     panel_specific["disease_associated_transcripts"] = list(disease_associated)
@@ -48,6 +54,7 @@ def add_panel_specific_gene_info(panel_info):
     panel_specific["manual_penetrance"] = manual_penetrance
     panel_specific["mosaicism"] = mosaicism
     panel_specific["manual_inheritance"] = list(manual_inheritance)
+    panel_specific["comment"] = comment
 
     return panel_specific
 
@@ -148,6 +155,29 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
         transcript["change_str"] = transcript_str(transcript, hgnc_symbol)
 
 
+def update_variant_case_panels(store, case_obj, variant_obj):
+    """Populate variant with case gene panels with info on e.g. if a panel was removed on variant_obj.
+    Variant objects panels are only a list of matching panel names.
+
+    The case_obj should be up to date first. Call update_case_panels() as needed in context:
+    to save some resources we do not call it here for each variant.
+
+    Args:
+        store(adapter.MongoAdapter)
+        case_obj(dict):     case_obj with updated panels - update_case_panels() first
+        variant_obj(dict)
+    """
+
+    variant_panel_names = variant_obj.get("panels") or []
+    case_panel_objs = [
+        panel
+        for panel in (case_obj.get("panels") or [])
+        if panel["panel_name"] in variant_panel_names
+    ]
+
+    variant_obj["case_panels"] = case_panel_objs
+
+
 def add_gene_info(store, variant_obj, gene_panels=None, genome_build=None):
     """Adds information to variant genes from hgnc genes and selected gene panels.
 
