@@ -4,6 +4,11 @@ from scout.constants import SPIDEX_HUMAN
 from scout.utils.convert import amino_acid_residue_change_3_to_1
 
 SHALLOW_REFERENCE_STR_LOCI = ["ARX", "HOXA13"]
+BEACON_LINK_TEMPLATE = (
+    "https://beacon-network.org/#/search?pos={this[position]}&"
+    "chrom={this[chromosome]}&allele={this[alternative]}&"
+    "ref={this[reference]}&rs={build}"
+)
 
 
 def add_gene_links(gene_obj, build=37):
@@ -367,11 +372,11 @@ def smart(smart_domain):
     return link.format(smart_domain)
 
 
-def varsome(build, refseq_id, protein_sequence_name):
+def varsome(build: int, refseq_id: str, protein_sequence_name: str):
     """Return a string corresponding to a link to varsome page
 
     Args:
-        build(str): chromosome build
+        build(int): chromosome build
         refseq_id(str): transcript refseq id
         protein_sequence_name(str): transcript sequence name
 
@@ -380,6 +385,9 @@ def varsome(build, refseq_id, protein_sequence_name):
     if not all([refseq_id, protein_sequence_name]):
         return None
 
+    if build == 37:
+        build = 19
+
     link = "https://varsome.com/variant/hg{}/{}:{}"
 
     return link.format(build, refseq_id, protein_sequence_name)
@@ -597,21 +605,13 @@ def cosmic_links(variant_obj):
     return cosmic_links
 
 
-def beacon_link(variant_obj, build=None):
+def beacon_link(variant_obj: dict, build: int):
     """Compose link to Beacon Network."""
-    build = build or 37
-    url_template = (
-        "https://beacon-network.org/#/search?pos={this[position]}&"
-        "chrom={this[chromosome]}&allele={this[alternative]}&"
-        "ref={this[reference]}&rs=GRCh37"
-    )
-    # beacon does not support build 38 at the moment
-    # if build == '38':
-    #     url_template = ("https://beacon-network.org/#/search?pos={this[position]}&"
-    #                     "chrom={this[chromosome]}&allele={this[alternative]}&"
-    #                     "ref={this[reference]}&rs=GRCh38")
+    url_template = BEACON_LINK_TEMPLATE
 
-    return url_template.format(this=variant_obj)
+    build = "GRCh38" if build == 38 else "GRCh37"
+
+    return url_template.format(this=variant_obj, build=build)
 
 
 def snp_links(variant_obj):
